@@ -126,7 +126,7 @@ _re_ipv4 = r"[^\w^\d]((25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(25[0-5]|2[0-4
 
 def _match_ips(text):
     try:
-        ips = re.finditer(_re_ipv4, text)
+        ips = re.finditer(_re_ipv4, ' {0} '.format(text))
         labels = {}
         for ip in ips:
             try:
@@ -160,7 +160,7 @@ class SimilarityLabelGenerator:
     def __init__(self, filename: str, platform='linux'):
         #print(filename)
         self._platform = platform
-        lines = open(filename).readlines()
+        lines = open(filename, encoding='utf-8').readlines()
         self._strings = []
         for s in lines:
             # s = s[:min(150, len(s))]
